@@ -12,6 +12,7 @@
 
 #include <cstdint>
 #include <string>
+#include <vector>
 
 class IAESDecrypter
 {
@@ -21,7 +22,7 @@ public:
   virtual void decrypt(const AP4_UI08* aes_key,
                        const AP4_UI08* aes_iv,
                        const AP4_UI08* src,
-                       std::string& dst,
+                       std::vector<uint8_t>& dst,
                        size_t dstOffset,
                        size_t& dataSize,
                        bool lastChunk) = 0;
@@ -29,7 +30,4 @@ public:
   virtual void ivFromSequence(uint8_t* buffer, uint64_t sid) = 0;
   virtual const std::string& getLicenseKey() const = 0;
   virtual bool RenewLicense(const std::string& pluginUrl) = 0;
-
-private:
-  std::string m_licenseKey;
 };
