@@ -20,16 +20,13 @@ namespace SESSION
 class ATTR_DLL_LOCAL CStream
 {
 public:
-  CStream(adaptive::AdaptiveTree& tree,
-          adaptive::AdaptiveTree::AdaptationSet* adp,
-          adaptive::AdaptiveTree::Representation* initialRepr,
-          const UTILS::PROPERTIES::KodiProperties& kodiProps,
-          bool chooseRep)
+  CStream(adaptive::AdaptiveTree* tree,
+          PLAYLIST::CAdaptationSet* adp,
+          PLAYLIST::CRepresentation* initialRepr)
     : m_isEnabled{false},
       m_isEncrypted{false},
       m_mainId{0},
-      m_adStream{tree, adp, initialRepr, kodiProps, chooseRep},
-      m_hasSegmentChanged{false},
+      m_adStream{tree, adp, initialRepr},
       m_isValid{true} {};
 
 
@@ -55,7 +52,7 @@ public:
    * \brief Set the stream sample reader
    * \param reader The reader
    */
-  void SetReader(std::unique_ptr<ISampleReader> reader) { m_streamReader = std::move(reader); }
+  void SetReader(std::unique_ptr<ISampleReader> reader);
 
   /*!
    * \brief Get the stream file handler pointer
@@ -89,7 +86,6 @@ public:
   uint16_t m_mainId;
   adaptive::AdaptiveStream m_adStream;
   kodi::addon::InputstreamInfo m_info;
-  bool m_hasSegmentChanged;
   bool m_isValid;
 
 private:
