@@ -8,12 +8,12 @@
 
 #pragma once
 
-#include "../SSD_dll.h"
-#include "../codechandler/CodecHandler.h"
-#include "../common/AdaptiveDecrypter.h"
-#include "../common/AdaptiveCencSampleDecrypter.h"
-#include "../utils/log.h"
 #include "SampleReader.h"
+#include "decrypters/IDecrypter.h"
+
+// forwards
+class CAdaptiveCencSampleDecrypter;
+class CodecHandler;
 
 class ATTR_DLL_LOCAL CFragmentedSampleReader : public ISampleReader, public AP4_LinearReader
 {
@@ -21,12 +21,14 @@ public:
   CFragmentedSampleReader(AP4_ByteStream* input,
                          AP4_Movie* movie,
                          AP4_Track* track,
-                         AP4_UI32 streamId,
-                         Adaptive_CencSingleSampleDecrypter* ssd,
-                         const SSD::SSD_DECRYPTER::SSD_CAPS& dcaps);
+                         AP4_UI32 streamId);
 
   ~CFragmentedSampleReader();
 
+  virtual bool Initialize(SESSION::CStream* stream) override;
+  virtual void SetDecrypter(Adaptive_CencSingleSampleDecrypter* ssd,
+                            const DRM::DecrypterCapabilites& dcaps) override;
+
   AP4_Result Start(bool& bStarted) override;
   AP4_Result ReadSample() override;
   void Reset(bool bEOS) override;
@@ -42,15 +44,11 @@ public:
   bool GetInformation(kodi::addon::InputstreamInfo& info) override;
   bool TimeSeek(uint64_t pts, bool preceeding) override;
   void SetPTSOffset(uint64_t offset) override;
-  uint64_t GetStartPTS() const override { return m_startPts; }
-  void SetStartPTS(uint64_t pts) override { m_startPts = pts; }
   int64_t GetPTSDiff() const override { return m_ptsDiff; }
-  bool GetNextFragmentInfo(uint64_t& ts, uint64_t& dur) override;
+  bool GetFragmentInfo(uint64_t& duration) override;
   uint32_t GetTimeScale() const override { return m_track->GetMediaTimeScale(); }
   CryptoInfo GetReaderCryptoInfo() const override { return m_readerCryptoInfo; }
 
-  static const AP4_UI32 TRACKID_UNKNOWN = -1;
-
 protected:
   AP4_Result ProcessMoof(AP4_ContainerAtom* moof,
                          AP4_Position moof_offset,
@@ -59,12 +57,13 @@ protected:
 
 private:
   void UpdateSampleDescription();
+  void ParseTrafTfrf(AP4_UuidAtom* uuidAtom);
 
   AP4_Track* m_track;
   AP4_UI32 m_poolId{0};
   AP4_UI32 m_streamId;
   AP4_UI32 m_sampleDescIndex{1};
-  SSD::SSD_DECRYPTER::SSD_CAPS m_decrypterCaps;
+  DRM::DecrypterCapabilites m_decrypterCaps;
   unsigned int m_failCount{0};
   bool m_bSampleDescChanged{false};
   bool m_eos{false};
@@ -72,19 +71,16 @@ private:
   int64_t m_dts{0};
   int64_t m_pts{0};
   int64_t m_ptsDiff{0};
-  uint64_t m_startPts{STREAM_NOPTS_VALUE};
   AP4_UI64 m_ptsOffs{~0ULL};
-  uint64_t m_timeBaseExt;
-  uint64_t m_timeBaseInt;
+  uint64_t m_timeBaseExt{0};
+  uint64_t m_timeBaseInt{0};
   AP4_Sample m_sample;
   AP4_DataBuffer m_encrypted;
   AP4_DataBuffer m_sampleData;
   CodecHandler* m_codecHandler{nullptr};
-  const AP4_UI08* m_defaultKey{nullptr};
+  std::vector<uint8_t> m_defaultKey;
   AP4_ProtectedSampleDescription* m_protectedDesc{nullptr};
-  Adaptive_CencSingleSampleDecrypter* m_singleSampleDecryptor;
+  Adaptive_CencSingleSampleDecrypter* m_singleSampleDecryptor{nullptr};
   CAdaptiveCencSampleDecrypter* m_decrypter{nullptr};
-  uint64_t m_nextDuration{0};
-  uint64_t m_nextTimestamp{0};
   CryptoInfo m_readerCryptoInfo{};
 };
