@@ -18,11 +18,11 @@ namespace UTILS
 namespace BASE64
 {
 
-void Encode(const uint8_t* input, const size_t length, std::string& output);
-std::string Encode(const uint8_t* input, const size_t length);
-std::string Encode(const std::vector<uint8_t>& input);
-std::string Encode(const std::vector<char>& input);
-std::string Encode(const std::string& input);
+void Encode(const uint8_t* input, const size_t length, std::string& output, const bool padding = true);
+std::string Encode(const uint8_t* input, const size_t length, const bool padding = true);
+std::string Encode(const std::vector<uint8_t>& input, const bool padding = true);
+std::string Encode(const std::vector<char>& input, const bool padding = true);
+std::string Encode(const std::string& input, const bool padding = true);
 
 void Decode(const char* input, const size_t length, std::vector<uint8_t>& output);
 std::vector<uint8_t> Decode(std::string_view input);
@@ -30,5 +30,7 @@ std::string DecodeToStr(std::string_view input);
 
 bool IsValidBase64(const std::string& input);
 
+bool AddPadding(std::string& base64str);
+
 } // namespace BASE64
 } // namespace UTILS
